@@ -27,7 +27,8 @@ console = getConsole()
 # Import raet libs
 from ..abiding import *  # import globals
 from .. import raeting
-from ..raeting import PcktKind, TailSize, CoatKind, FootSize, FootKind, BodyKind, HeadKind
+from ..raeting import (PcktKind, TailSize, CoatKind, FootSize, FootKind,
+                       BodyKind, HeadKind, TrnsKind)
 
 class Part(object):
     '''
@@ -449,6 +450,7 @@ class RxFoot(Foot):
         '''
         fk = self.packet.data['fk']
         fl = self.packet.data['fl']
+        tk = self.packet.data['tk']
         self.packed = b''
 
         if fk not in list(FootKind):
@@ -462,6 +464,11 @@ class RxFoot(Foot):
 
         self.packed = self.packet.packed[self.packet.size - fl:]
 
+        if self.packet.stack.veritive and tk == TrnsKind.message and fk != FootKind.nacl:
+            reason = "missing signature"
+            emsg = "Failed verification: {0}".format(reason)
+            raise raeting.PacketError(emsg)
+
         if fk == FootKind.nacl:
             if self.size != FootSize.nacl:
                 emsg = ("Actual foot size '{0}' does not match "
@@ -475,7 +482,11 @@ class RxFoot(Foot):
 
             msg = front + blank
             if not self.packet.verify(signature, msg):
-                emsg = "Failed verification"
+                if self.packet.data['de'] not in self.packet.stack.remotes:
+                    reason =  "nuid not in remotes"
+                else:
+                    reason = "key invalid"
+                emsg = "Failed verification: {0}".format(reason)
                 raise raeting.PacketError(emsg)
 
         if fk == FootKind.nada:
