@@ -9,7 +9,7 @@ else:
     import unittest
 import os
 
-from ioflo import test
+from raet import test
 from ioflo.base.consoling import getConsole
 console = getConsole()
 console.reinit(verbosity=console.Wordage.concise)
@@ -17,4 +17,4 @@ console.reinit(verbosity=console.Wordage.concise)
 top = os.path.dirname(os.path.abspath(sys.modules.get(__name__).__file__))
 
 if __name__ == "__main__":
-    test.run(top)
+    test.run(top, failfast=True)
